@@ -438,19 +438,23 @@ class EveSolarSystem(EveUniverse):
         children = {"planets": "EvePlanet"}
 
     @property
-    def is_high_sec(self):
-        return self.security_status > 0.5
+    def is_high_sec(self) -> bool:
+        """returns True if this solar system is in high sec, else False"""
+        return round(self.security_status, 1) >= 0.5
 
     @property
-    def is_low_sec(self):
-        return 0 < self.security_status <= 0.5
+    def is_low_sec(self) -> bool:
+        """returns True if this solar system is in low sec, else False"""
+        return 0 < round(self.security_status, 1) < 0.5
 
     @property
-    def is_null_sec(self):
-        return self.security_status <= 0 and not self.is_w_space
+    def is_null_sec(self) -> bool:
+        """returns True if this solar system is in null sec, else False"""
+        return round(self.security_status, 1) <= 0 and not self.is_w_space
 
     @property
-    def is_w_space(self):
+    def is_w_space(self) -> bool:
+        """returns True if this solar system is in wormhole space, else False"""
         return 31000000 <= self.id < 32000000
 
     @property
